@@ -1,5 +1,5 @@
 """Top-level package for COVID-19 Outbreak Simulator."""
 
 __author__ = """COVID-19 Outbreak Simulator"""
-__email__ = 'ben.bob@gmail.com'
-__version__ = '0.5.0'
\ No newline at end of file
+__email__ = 'bo.peng@bcm.edu'
+__version__ = '0.5.1'
\ No newline at end of file
