@@ -63,16 +63,18 @@ def test_plugin_quarantine(clear_log):
     ])
 
     main([
-        '--jobs', '1', '--popsize', 'A=100', 'B=200', '--repeats', '100', '--plugin', 'quarantine',
-        '--duration', '7', '--proportion', 'A=1', 'B=0', '--target', 'all'
+        '--jobs', '1', '--popsize', 'A=100', 'B=200', '--repeats', '100',
+        '--plugin', 'quarantine', '--duration', '7', '--proportion', 'A=1',
+        'B=0', '--target', 'all'
     ])
 
     main([
         '--jobs', '1', '--popsize', 'A=100', 'B=200', '--infector', 'A_10',
-        '--repeats', '100', '--plugin', 'quarantine',
-        '--duration', '7', '--proportion', 'A=1', 'B=0', '--target', 'infected'
+        '--repeats', '100', '--plugin', 'quarantine', '--duration', '7',
+        '--proportion', 'A=1', 'B=0', '--target', 'infected'
     ])
 
+
 def test_plugin_quarantine_error(clear_log):
     with pytest.raises((Exception, SystemExit)):
         main([
@@ -88,10 +90,11 @@ def test_plugin_quarantine_error(clear_log):
 
     with pytest.raises((Exception, SystemExit)):
         main([
-            '--jobs', '1', '--repeats', '100', '--plugin', 'quarantine', '--proportion', '0.5',
-            '--target', 'somethingelse'
+            '--jobs', '1', '--repeats', '100', '--plugin', 'quarantine',
+            '--proportion', '0.5', '--target', 'somethingelse'
         ])
 
+
 def test_plugin_stat():
     main([
         '--jobs', '1', '--repeats', '100', '--plugin', 'stat', '--interval', '1'
@@ -111,13 +114,15 @@ def test_plugin_init():
         '--incidence-rate', '0.01'
     ])
     main([
-        '--jobs', '1', '--repeats', '100', '--popsize', 'A=100', 'B=200', '--plugin',
-        'init', '--at', '0', '--incidence-rate', '1', 'A=0.01', 'B=0.02', '--leadtime', 'any'
+        '--jobs', '1', '--repeats', '100', '--popsize', 'A=100', 'B=200',
+        '--plugin', 'init', '--at', '0', '--incidence-rate', '1', 'A=0.01',
+        'B=0.02', '--leadtime', 'any'
     ])
     main([
-        '--jobs', '1', '--repeats', '100', '--popsize', 'A=100', 'B=200', '--plugin',
-        'init', '--at', '0', '--incidence-rate', '1', 'A=0.01', 'B=0.02',
-        '--seroprevalence', '1', 'A=0.02', 'B=0.04', '--leadtime', 'asymptomatic'
+        '--jobs', '1', '--repeats', '100', '--popsize', 'A=100', 'B=200',
+        '--plugin', 'init', '--at', '0', '--incidence-rate', '1', 'A=0.01',
+        'B=0.02', '--seroprevalence', '1', 'A=0.02', 'B=0.04', '--leadtime',
+        'asymptomatic'
     ])
 
 
@@ -180,8 +185,8 @@ def test_plugin_remove():
         'remove', '2', '--at', '1'
     ])
     main([
-        '--jobs', '1', '--repeats', '100', '--popsize', 'A=100', 'B=100', '--stop-if', 't>10', '--plugin',
-        'remove', 'A=2', '--interval', '1'
+        '--jobs', '1', '--repeats', '100', '--popsize', 'A=100', 'B=100',
+        '--stop-if', 't>10', '--plugin', 'remove', 'A=2', '--interval', '1'
     ])
 
 
@@ -191,8 +196,9 @@ def test_plugin_community_infection():
         'community_infection', '--probability', '0.0001', '--interval', '1'
     ])
     main([
-        '--jobs', '1', '--repeats', '10', '--popsize', 'A=100', 'B=200', '--stop-if', 't>4', '--plugin',
-        'community_infection', '--probability', '1', 'A=0.0001', '--interval', '1'
+        '--jobs', '1', '--repeats', '10', '--popsize', 'A=100', 'B=200',
+        '--stop-if', 't>4', '--plugin', 'community_infection', '--probability',
+        '1', 'A=0.0001', '--interval', '1'
     ])
 
 
@@ -215,5 +221,24 @@ def test_plugin_testing():
         '--handle-positive', 'quarantine_7'
     ])
 
-    main(['--jobs', '1', '--repeats', '100', '--plugin', 'testing', '1', '2',
-        '--turnaround-time', '2'])
+    main([
+        '--jobs', '1', '--repeats', '100', '--plugin', 'testing', '1', '2',
+        '--turnaround-time', '2'
+    ])
+
+
+def test_plugin_vaccinate():
+    main(['--jobs', '1', '--repeats', '100', '--plugin', 'vaccinate'])
+
+    main(['--jobs', '1', '--repeats', '100', '--plugin', 'vaccinate', '1', '2'])
+
+    main([
+        '--jobs', '1', '--repeats', '100', '--popsize', 'A=100', 'B=200',
+        '--infector', 'A_2', 'A_7', '--plugin', 'vaccinate', 'A_2', 'A_7',
+        '--infectivity', '0.5'
+    ])
+
+    main([
+        '--jobs', '1', '--repeats', '100', '--plugin', 'vaccinate', '1', '2',
+        '--immunity', '0.7'
+    ])
